/* gtkextra - set of widgets for gtk+
 * Copyright 1999-2001  Adrian E. Feiguin <feiguin@ifir.edu.ar>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef GTK_EXTRA_H
#define GTK_EXTRA_H

#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <glib.h>

#include <gtkextra/gtkbordercombo.h>
#include <gtkextra/gtkcharsel.h>
#include <gtkextra/gtkcheckitem.h>
#include <gtkextra/gtkcolorcombo.h>
#include <gtkextra/gtkcombobox.h>
#include <gtkextra/gtkdirtree.h>
#include <gtkextra/gtkextrafeatures.h>
#include <gtkextra/gtkfilelist.h>
#include <gtkextra/gtkfontcombo.h>
#include <gtkextra/gtkiconlist.h>
#include <gtkextra/gtkitementry.h>
#include <gtkextra/gtkiconfilesel.h>
#include <gtkextra/gtkplot.h>
#include <gtkextra/gtkplotpolar.h>
#include <gtkextra/gtkplot3d.h>
#include <gtkextra/gtkplotdata.h>
#include <gtkextra/gtkplotsurface.h>
#include <gtkextra/gtkplotcsurface.h>
#include <gtkextra/gtkplotcanvas.h>
#include <gtkextra/gtkplotbar.h>
#include <gtkextra/gtkplotbox.h>
#include <gtkextra/gtkplotdt.h>
#include <gtkextra/gtkplotflux.h>
#include <gtkextra/gtkplotpixmap.h>
#include <gtkextra/gtkplotgdk.h>
#include <gtkextra/gtkplotpc.h>
#include <gtkextra/gtkplotprint.h>
#include <gtkextra/gtkplotps.h>
#include <gtkextra/gtkpsfont.h>
#include <gtkextra/gtksheet.h>
#include <gtkextra/gtktogglecombo.h>


#endif /* GTK_EXTRA_H */
